==> kubernetes-model-resource-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimListFluent<A extends ResourceClaimListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ResourceClaim item);
  public A setToItems(Integer index,ResourceClaim item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public A addAllToItems(Collection<ResourceClaim> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public A removeAllFromItems(Collection<ResourceClaim> items);
  public A removeMatchingFromItems(Predicate<ResourceClaimBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaim> getItems();
  public List<ResourceClaim> buildItems();
  public ResourceClaim buildItem(Integer index);
  public ResourceClaim buildFirstItem();
  public ResourceClaim buildLastItem();
  public ResourceClaim buildMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public A withItems(List<ResourceClaim> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public Boolean hasItems();
  public ResourceClaimListFluent.ItemsNested<A> addNewItem();
  public ResourceClaimListFluent.ItemsNested<A> addNewItemLike(ResourceClaim item);
  public ResourceClaimListFluent.ItemsNested<A> setNewItemLike(Integer index,ResourceClaim item);
  public ResourceClaimListFluent.ItemsNested<A> editItem(Integer index);
  public ResourceClaimListFluent.ItemsNested<A> editFirstItem();
  public ResourceClaimListFluent.ItemsNested<A> editLastItem();
  public ResourceClaimListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ResourceClaimFluent<ResourceClaimListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimListFluent<A extends ResourceClaimListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ResourceClaim item);
  public A setToItems(int index,ResourceClaim item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public A addAllToItems(Collection<ResourceClaim> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public A removeAllFromItems(Collection<ResourceClaim> items);
  public A removeMatchingFromItems(Predicate<ResourceClaimBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaim> getItems();
  public List<ResourceClaim> buildItems();
  public ResourceClaim buildItem(int index);
  public ResourceClaim buildFirstItem();
  public ResourceClaim buildLastItem();
  public ResourceClaim buildMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public A withItems(List<ResourceClaim> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaim... items);
  public Boolean hasItems();
  public ResourceClaimListFluent.ItemsNested<A> addNewItem();
  public ResourceClaimListFluent.ItemsNested<A> addNewItemLike(ResourceClaim item);
  public ResourceClaimListFluent.ItemsNested<A> setNewItemLike(int index,ResourceClaim item);
  public ResourceClaimListFluent.ItemsNested<A> editItem(int index);
  public ResourceClaimListFluent.ItemsNested<A> editFirstItem();
  public ResourceClaimListFluent.ItemsNested<A> editLastItem();
  public ResourceClaimListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceClaimBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ResourceClaimFluent<ResourceClaimListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
